# function to print results
printResults <- function( comparison, pValue, cliffDelta, effectSize, confInt ) {
	levels <- c("negligible", "small", "medium", "large")
	cat("Data: ", comparison, "\n")
	cat("p-value: ", pValue, "\n", "cliff delta: ", cliffDelta, "\n")
	cat(levels[effectSize], ", Confidence Interval: ", confInt, "\n\n")
}

# get the list of files
filesToProcess <- Sys.glob('/Users/tomnarock/Desktop/results/results_*.txt')

# empty vectors for later analysis
# similarity
ssp01 <- c(); ssp02 <- c(); ssp03 <- c(); ssp04 <- c(); ssp05 <- c(); snp01 <- c(); snp02 <- c();
snp03 <- c(); snp04 <- c(); snp05 <- c(); csp01 <- c(); csp02 <- c(); csp03 <- c(); csp04 <- c();
csp05 <- c(); cnp01 <- c(); cnp02 <- c(); cnp03 <- c(); cnp04 <- c(); cnp05 <- c()
# decision confidence
sdp01 <- c(); sdp02 <- c(); sdp03 <- c(); sdp04 <- c(); sdp05 <- c(); sdn01 <- c(); sdn02 <- c();
sdn03 <- c(); sdn04 <- c(); sdn05 <- c(); cdp01 <- c(); cdp02 <- c(); cdp03 <- c(); cdp04 <- c();
cdp05 <- c(); cdn01 <- c(); cdn02 <- c(); cdn03 <- c(); cdn04 <- c(); cdn05 <- c()
# relative advantage
srp01 <- c(); srp02 <- c(); srp03 <- c(); srp04 <- c(); srp05 <- c(); srn01 <- c(); srn02 <- c();
srn03 <- c(); srn04 <- c(); srn05 <- c(); crp01 <- c(); crp02 <- c(); crp03 <- c(); crp04 <- c();
crp05 <- c(); crn01 <- c(); crn02 <- c(); crn03 <- c(); crn04 <- c(); crn05 <- c()

# most things in R can be done without loops
# thus, there is likely a better way to do this
n <- length(filesToProcess)
for( i in 1:n ) {

  # read the file
  fileData <- read.csv(file=filesToProcess[i], head=FALSE, sep=",")

  # get the size of the data frame
  nr <- nrow(fileData)
  
  # valid survey results have 21 rows
  # if we have less then that the participant did not complete the survey
  # here we keep only the completed surveys, we have 49
  if ( nr == 21 ) { 
  	
  	 # seperate into service provenance and non-service provenance
  	 # the 9th column is the name of the service description
  	 # grab the row by which service pair it is associated with
  	 #
  	 # simple with service provenance
  	 s_sp_01 <- fileData[fileData$V9 == './data/12_pw_1_sp.txt',]
  	 s_sp_02 <- fileData[fileData$V9 == './data/06_pw_2_sp.txt',]
  	 s_sp_03 <- fileData[fileData$V9 == './data/03_pw_5_sp.txt',]
  	 s_sp_04 <- fileData[fileData$V9 == './data/geo_new_sp_03.txt',]
  	 s_sp_05 <- fileData[fileData$V9 == './data/geo_new_sp_04.txt',]
  	 # simple without service provenance
  	 s_np_01 <- fileData[fileData$V9 == './data/04_pw_1.txt',]
  	 s_np_02 <- fileData[fileData$V9 == './data/10_pw_2.txt',]
  	 s_np_03 <- fileData[fileData$V9 == './data/09_pw_5.txt',]
	 s_np_04 <- fileData[fileData$V9 == './data/geo_new_03.txt',]
  	 s_np_05 <- fileData[fileData$V9 == './data/geo_new_04.txt',]
     # complex with service provenance
  	 c_sp_01 <- fileData[fileData$V9 == './data/01_pw_3_sp.txt',]
  	 c_sp_02 <- fileData[fileData$V9 == './data/07_pw_4_sp.txt',]
  	 c_sp_03 <- fileData[fileData$V9 == './data/11_pw_6_sp.txt',]
  	 c_sp_04 <- fileData[fileData$V9 == './data/geo_new_sp_01.txt',]
  	 c_sp_05 <- fileData[fileData$V9 == './data/geo_new_sp_06.txt',]
  	 # complex without service provenance
  	 c_np_01 <- fileData[fileData$V9 == './data/05_pw_3.txt',] 
  	 c_np_02 <- fileData[fileData$V9 == './data/02_pw_4.txt',]
  	 c_np_03 <- fileData[fileData$V9 == './data/08_pw_6.txt',]
  	 c_np_04 <- fileData[fileData$V9 == './data/geo_new_01.txt',]
  	 c_np_05 <- fileData[fileData$V9 == './data/geo_new_06.txt',]
  	
  	 # extend the vectors
  	 # similarity
  	 ssp01 <- c( ssp01, as.numeric(as.character(s_sp_01$V1 )))
  	 ssp02 <- c( ssp02, as.numeric(as.character(s_sp_02$V1 )))
  	 ssp03 <- c( ssp03, as.numeric(as.character(s_sp_03$V1 )))
  	 ssp04 <- c( ssp04, as.numeric(as.character(s_sp_04$V1 )))
  	 ssp05 <- c( ssp05, as.numeric(as.character(s_sp_05$V1 )))
  	 #
  	 snp01 <- c( snp01, as.numeric(as.character(s_np_01$V1 )))
  	 snp02 <- c( snp02, as.numeric(as.character(s_np_02$V1 )))
  	 snp03 <- c( snp03, as.numeric(as.character(s_np_03$V1 )))
  	 snp04 <- c( snp04, as.numeric(as.character(s_np_04$V1 )))
  	 snp05 <- c( snp05, as.numeric(as.character(s_np_05$V1 )))
  	 #
  	 csp01 <- c( csp01, as.numeric(as.character(c_sp_01$V1 )))
  	 csp02 <- c( csp02, as.numeric(as.character(c_sp_02$V1 )))
  	 csp03 <- c( csp03, as.numeric(as.character(c_sp_03$V1 )))
  	 csp04 <- c( csp04, as.numeric(as.character(c_sp_04$V1 )))
  	 csp05 <- c( csp05, as.numeric(as.character(c_sp_05$V1 )))
  	 #
  	 cnp01 <- c( cnp01, as.numeric(as.character(c_np_01$V1 )))
  	 cnp02 <- c( cnp02, as.numeric(as.character(c_np_02$V1 )))
  	 cnp03 <- c( cnp03, as.numeric(as.character(c_np_03$V1 )))
  	 cnp04 <- c( cnp04, as.numeric(as.character(c_np_04$V1 )))
  	 cnp05 <- c( cnp05, as.numeric(as.character(c_np_05$V1 )))
  	 # decision confidence
  	 sdp01 <- c( sdp01, as.numeric(as.character(s_sp_01$V2)), as.numeric(as.character(s_sp_01$V3)), 	 
  	                    as.numeric(as.character(s_sp_01$V4 )))
  	 sdp02 <- c( sdp02, as.numeric(as.character(s_sp_02$V2)), as.numeric(as.character(s_sp_02$V3)), 
  	 					as.numeric(as.character(s_sp_02$V4 )))
  	 sdp03 <- c( sdp03, as.numeric(as.character(s_sp_03$V2)), as.numeric(as.character(s_sp_03$V3)), 
  	 					as.numeric(as.character(s_sp_03$V4 )))
  	 sdp04 <- c( sdp04, as.numeric(as.character(s_sp_04$V2)), as.numeric(as.character(s_sp_04$V3)), 
  	 					as.numeric(as.character(s_sp_04$V4 )))
  	 sdp05 <- c( sdp05, as.numeric(as.character(s_sp_05$V2)), as.numeric(as.character(s_sp_05$V3)), 
  	 					as.numeric(as.character(s_sp_05$V4 )))
  	 #
  	 sdn01 <- c( sdn01, as.numeric(as.character(s_np_01$V2)), as.numeric(as.character(s_np_01$V3)), 
  	 					as.numeric(as.character(s_np_01$V4 )))
  	 sdn02 <- c( sdn02, as.numeric(as.character(s_np_02$V2)), as.numeric(as.character(s_np_02$V3)), 
  	 					as.numeric(as.character(s_np_02$V4 )))
  	 sdn03 <- c( sdn03, as.numeric(as.character(s_np_03$V2)), as.numeric(as.character(s_np_03$V3)), 
  	 					as.numeric(as.character(s_np_03$V4 )))
  	 sdn04 <- c( sdn04, as.numeric(as.character(s_np_04$V2)), as.numeric(as.character(s_np_04$V3)), 
  	 					as.numeric(as.character(s_np_04$V4 )))
  	 sdn05 <- c( sdn05, as.numeric(as.character(s_np_05$V2)), as.numeric(as.character(s_np_05$V3)), 
  	 					as.numeric(as.character(s_np_05$V4 )))
  	 #
  	 cdp01 <- c( cdp01, as.numeric(as.character(c_sp_01$V2)), as.numeric(as.character(c_sp_01$V3)), 
  	 					as.numeric(as.character(c_sp_01$V4 )))
  	 cdp02 <- c( cdp02, as.numeric(as.character(c_sp_02$V2)), as.numeric(as.character(c_sp_02$V3)), 
  	 					as.numeric(as.character(c_sp_02$V4 )))
  	 cdp03 <- c( cdp03, as.numeric(as.character(c_sp_03$V2)), as.numeric(as.character(c_sp_03$V3)), 
  	 					as.numeric(as.character(c_sp_03$V4 )))
  	 cdp04 <- c( cdp04, as.numeric(as.character(c_sp_04$V2)), as.numeric(as.character(c_sp_04$V3)), 
  	 					as.numeric(as.character(c_sp_04$V4 )))
  	 cdp05 <- c( cdp05, as.numeric(as.character(c_sp_05$V2)), as.numeric(as.character(c_sp_05$V3)), 
  	 					as.numeric(as.character(c_sp_05$V4 )))
  	 #
  	 cdn01 <- c( cdn01, as.numeric(as.character(c_np_01$V2)), as.numeric(as.character(c_np_01$V3)), 
  	 					as.numeric(as.character(c_np_01$V4 )))
  	 cdn02 <- c( cdn02, as.numeric(as.character(c_np_02$V2)), as.numeric(as.character(c_np_02$V3)), 
  	 					as.numeric(as.character(c_np_02$V4 )))
  	 cdn03 <- c( cdn03, as.numeric(as.character(c_np_03$V2)), as.numeric(as.character(c_np_03$V3)), 
  	 					as.numeric(as.character(c_np_03$V4 )))
  	 cdn04 <- c( cdn04, as.numeric(as.character(c_np_04$V2)), as.numeric(as.character(c_np_04$V3)), 
  	 					as.numeric(as.character(c_np_04$V4 )))
  	 cdn05 <- c( cdn05, as.numeric(as.character(c_np_05$V2)), as.numeric(as.character(c_np_05$V3)), 
  	 					as.numeric(as.character(c_np_05$V4 )))
  	 # relative advantage
  	 srp01 <- c( srp01, as.numeric(as.character(s_sp_01$V5)), as.numeric(as.character(s_sp_01$V6)), 
  	 					as.numeric(as.character(s_sp_01$V7 )))
  	 srp02 <- c( srp02, as.numeric(as.character(s_sp_02$V5)), as.numeric(as.character(s_sp_02$V6)), 
  	 					as.numeric(as.character(s_sp_02$V7 )))
  	 srp03 <- c( srp03, as.numeric(as.character(s_sp_03$V5)), as.numeric(as.character(s_sp_03$V6)), 
  	 					as.numeric(as.character(s_sp_03$V7 )))
  	 srp04 <- c( srp04, as.numeric(as.character(s_sp_04$V5)), as.numeric(as.character(s_sp_04$V6)), 
  	 					as.numeric(as.character(s_sp_04$V7 )))
  	 srp05 <- c( srp05, as.numeric(as.character(s_sp_05$V5)), as.numeric(as.character(s_sp_05$V6)), 
  	 					as.numeric(as.character(s_sp_05$V7 )))
  	 #
  	 srn01 <- c( srn01, as.numeric(as.character(s_np_01$V5)), as.numeric(as.character(s_np_01$V6)), 
  	 					as.numeric(as.character(s_np_01$V7 )))
  	 srn02 <- c( srn02, as.numeric(as.character(s_np_02$V5)), as.numeric(as.character(s_np_02$V6)), 
  	 					as.numeric(as.character(s_np_02$V7 )))
  	 srn03 <- c( srn03, as.numeric(as.character(s_np_03$V5)), as.numeric(as.character(s_np_03$V6)), 
  	 					as.numeric(as.character(s_np_03$V7 )))
  	 srn04 <- c( srn04, as.numeric(as.character(s_np_04$V5)), as.numeric(as.character(s_np_04$V6)), 
  	 					as.numeric(as.character(s_np_04$V7 )))
  	 srn05 <- c( srn05, as.numeric(as.character(s_np_05$V5)), as.numeric(as.character(s_np_05$V6)), 
  	 					as.numeric(as.character(s_np_05$V7 )))
  	 #
  	 crp01 <- c( crp01, as.numeric(as.character(c_sp_01$V5)), as.numeric(as.character(c_sp_01$V6)), 
  	 					as.numeric(as.character(c_sp_01$V7 )))
  	 crp02 <- c( crp02, as.numeric(as.character(c_sp_02$V5)), as.numeric(as.character(c_sp_02$V6)), 
  	 					as.numeric(as.character(c_sp_02$V7 )))
  	 crp03 <- c( crp03, as.numeric(as.character(c_sp_03$V5)), as.numeric(as.character(c_sp_03$V6)), 
  	 					as.numeric(as.character(c_sp_03$V7 )))
  	 crp04 <- c( crp04, as.numeric(as.character(c_sp_04$V5)), as.numeric(as.character(c_sp_04$V6)), 
  	 					as.numeric(as.character(c_sp_04$V7 )))
  	 crp05 <- c( crp05, as.numeric(as.character(c_sp_05$V5)), as.numeric(as.character(c_sp_05$V6)), 
  	 					as.numeric(as.character(c_sp_05$V7 )))
  	 #
  	 crn01 <- c( crn01, as.numeric(as.character(c_np_01$V5)), as.numeric(as.character(c_np_01$V6)), 
  	 					as.numeric(as.character(c_np_01$V7 )))
  	 crn02 <- c( crn02, as.numeric(as.character(c_np_02$V5)), as.numeric(as.character(c_np_02$V6)), 		
  	 					as.numeric(as.character(c_np_02$V7 )))
  	 crn03 <- c( crn03, as.numeric(as.character(c_np_03$V5)), as.numeric(as.character(c_np_03$V6)), 
  	 					as.numeric(as.character(c_np_03$V7 )))
  	 crn04 <- c( crn04, as.numeric(as.character(c_np_04$V5)), as.numeric(as.character(c_np_04$V6)), 
  	 					as.numeric(as.character(c_np_04$V7 )))
  	 crn05 <- c( crn05, as.numeric(as.character(c_np_05$V5)), as.numeric(as.character(c_np_05$V6)), 
  	 					as.numeric(as.character(c_np_05$V7 )))
  	 	  			  
  }

}

# using mtorchiano's library for effect size
# available here: https://github.com/mtorchiano/effsize/ 
library(effsize)

# labels for printing results
simple <- c("1", "2", "5", "geo_03", "geo_04")
complex <- c("3", "4", "6", "geo_01", "geo_06")

# Wilcoxon signed rank test
#
# similarity
#
print("Similarity: Simple Services")
r <- wilcox.test(ssp01, snp01, paired=TRUE) 
res = cliff.delta(ssp01,snp01)
printResults(simple[1], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(ssp02, snp02, paired=TRUE) 
res = cliff.delta(ssp02,snp02)
printResults(simple[2], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(ssp03, snp03, paired=TRUE) 
res = cliff.delta(ssp03,snp03)
printResults(simple[3], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(ssp04, snp04, paired=TRUE) 
res = cliff.delta(ssp04,snp04)
printResults(simple[4], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(ssp05, snp05, paired=TRUE) 
res = cliff.delta(ssp05,snp05)
printResults(simple[5], r$p.value, res$estimate, res$magnitude, res$conf.int)
#
print("Similarity: Complex Services")
r <- wilcox.test(csp01, cnp01, paired=TRUE) 
res = cliff.delta(csp01,cnp01)
printResults(complex[1], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(csp02, cnp02, paired=TRUE) 
res = cliff.delta(csp02,cnp02)
printResults(complex[2], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(csp03, cnp03, paired=TRUE) 
res = cliff.delta(csp03,cnp03)
printResults(complex[3], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(csp04, cnp04, paired=TRUE) 
res = cliff.delta(csp04,cnp04)
printResults(complex[4], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(csp05, cnp05, paired=TRUE) 
res = cliff.delta(csp05,cnp05)
printResults(complex[5], r$p.value, res$estimate, res$magnitude, res$conf.int)
#
# decision confidence
#
print("Decision Confidence: Simple Services")
r <- wilcox.test(sdp01, sdn01, paired=TRUE) 
res = cliff.delta(sdp01,sdn01)
printResults(simple[1], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(sdp02, sdn02, paired=TRUE) 
res = cliff.delta(sdp02,sdn02)
printResults(simple[2], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(sdp03, sdn03, paired=TRUE) 
res = cliff.delta(sdp03,sdn03)
printResults(simple[3], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(sdp04, sdn04, paired=TRUE) 
res = cliff.delta(sdp04,sdn04)
printResults(simple[4], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(sdp05, sdn05, paired=TRUE) 
res = cliff.delta(sdp05,sdn05)
printResults(simple[5], r$p.value, res$estimate, res$magnitude, res$conf.int)
#
print("Decision Confidence: Complex Services")
r <- wilcox.test(cdp01, cdn01, paired=TRUE) 
res = cliff.delta(cdp01,cdn01)
printResults(complex[1], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(cdp02, cdn02, paired=TRUE) 
res = cliff.delta(cdp02,cdn02)
printResults(complex[2], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(cdp03, cdn03, paired=TRUE) 
res = cliff.delta(cdp03,cdn03)
printResults(complex[3], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(cdp04, cdn04, paired=TRUE) 
res = cliff.delta(cdp04,cdn04)
printResults(complex[4], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(cdp05, cdn05, paired=TRUE) 
res = cliff.delta(cdp05,cdn05)
printResults(complex[5], r$p.value, res$estimate, res$magnitude, res$conf.int)
#
# relative advantage
#
print("Relative Advantage: Simple Services")
r <- wilcox.test(srp01, srn01, paired=TRUE) 
res = cliff.delta(srp01,srn01)
printResults(simple[1], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(srp02, srn02, paired=TRUE) 
res = cliff.delta(srp02,srn02)
printResults(simple[2], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(srp03, srn03, paired=TRUE) 
res = cliff.delta(srp03,srn03)
printResults(simple[3], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(srp04, srn04, paired=TRUE) 
res = cliff.delta(srp04,srn04)
printResults(simple[4], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(srp05, srn05, paired=TRUE) 
res = cliff.delta(srp05,srn05)
printResults(simple[5], r$p.value, res$estimate, res$magnitude, res$conf.int)
#
print("Relative Advantage: Complex Services")
r <- wilcox.test(crp01, crn01, paired=TRUE) 
res = cliff.delta(crp01,crn01)
printResults(complex[1], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(crp02, crn02, paired=TRUE) 
res = cliff.delta(crp02,crn02)
printResults(complex[2], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(crp03, crn03, paired=TRUE) 
res = cliff.delta(crp03,crn03)
printResults(complex[3], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(crp04, crn04, paired=TRUE) 
res = cliff.delta(crp04,crn04)
printResults(complex[4], r$p.value, res$estimate, res$magnitude, res$conf.int)

r <- wilcox.test(crp05, crn05, paired=TRUE) 
res = cliff.delta(crp05,crn05)
printResults(complex[5], r$p.value, res$estimate, res$magnitude, res$conf.int)

## Simple - service provenance vs. no provenance
s_sp <- c( ssp01, ssp02, ssp03, ssp04, ssp05 )
s_np <- c( snp01, snp02, snp03, snp04, snp05 )
r <- wilcox.test(s_sp, s_np, paired=TRUE) 
res = cliff.delta(s_sp, s_np)
printResults("Similarity: Simple", r$p.value, res$estimate, res$magnitude, res$conf.int)

## Complex - service provenance vs. no provenance
c_sp <- c( csp01, csp02, csp03, csp04, csp05 )
c_np <- c( cnp01, cnp02, cnp03, cnp04, cnp05 )
r <- wilcox.test(c_sp, c_np, paired=TRUE) 
res = cliff.delta(c_sp, c_np)
printResults("Similarity: Complex", r$p.value, res$estimate, res$magnitude, res$conf.int)

## All - servce provenance vs. no provenance
sp <- c( s_sp, c_sp )
np <- c( s_np, c_np )
r <- wilcox.test(sp, np, paired=TRUE) 
res = cliff.delta(sp, np)
printResults("Similarity: All", r$p.value, res$estimate, res$magnitude, res$conf.int)

# Decision Confidence

## Simple - service provenance vs. no provenance
s_sp <- c( sdp01, sdp02, sdp03, sdp04, sdp05 )
s_np <- c( sdn01, sdn02, sdn03, sdn04, sdn05 )
r <- wilcox.test(s_sp, s_np, paired=TRUE) 
res = cliff.delta(s_sp, s_np)
printResults("Decision Confidence: Simple", r$p.value, res$estimate, res$magnitude, res$conf.int)

## Complex - service provenance vs. no provenance
c_sp <- c( cdp01, cdp02, cdp03, cdp04, cdp05 )
c_np <- c( cdn01, cdn02, cdn03, cdn04, cdn05 )
r <- wilcox.test(c_sp, c_np, paired=TRUE) 
res = cliff.delta(c_sp, c_np)
printResults("Decision Confidence: Complex", r$p.value, res$estimate, res$magnitude, res$conf.int)

## All - servce provenance vs. no provenance
sp <- c( s_sp, c_sp )
np <- c( s_np, c_np )
r <- wilcox.test(sp, np, paired=TRUE) 
res = cliff.delta(sp, np)
printResults("Decision Confidence: All", r$p.value, res$estimate, res$magnitude, res$conf.int)

# Relative Advantage

## Simple - service provenance vs. no provenance
s_sp <- c( srp01, srp02, srp03, srp04, srp05 )
s_np <- c( srn01, srn02, srn03, srn04, srn05 )
r <- wilcox.test(s_sp, s_np, paired=TRUE) 
res = cliff.delta(s_sp, s_np)
printResults("Relative Advantage: Simple", r$p.value, res$estimate, res$magnitude, res$conf.int)

## Complex - service provenance vs. no provenance
c_sp <- c( crp01, crp02, crp03, crp04, crp05 )
c_np <- c( crn01, crn02, crn03, crn04, crn05 )
r <- wilcox.test(c_sp, c_np, paired=TRUE) 
res = cliff.delta(c_sp, c_np)
printResults("Relative Advantage: Complex", r$p.value, res$estimate, res$magnitude, res$conf.int)

## All - servce provenance vs. no provenance
sp <- c( s_sp, c_sp )
np <- c( s_np, c_np )
r <- wilcox.test(sp, np, paired=TRUE) 
res = cliff.delta(sp, np)
printResults("Relative Advantage: All", r$p.value, res$estimate, res$magnitude, res$conf.int)